==> openshift-model-operatorhub-5.0.0-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/CatalogSourceStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface CatalogSourceStatusFluent<A extends CatalogSourceStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildConfigMapReference instead.
 * @return The buildable object.
 */
@Deprecated public ConfigMapResourceReference getConfigMapReference();
    public ConfigMapResourceReference buildConfigMapReference();
    public A withConfigMapReference(ConfigMapResourceReference configMapReference);
    public Boolean hasConfigMapReference();
    public A withNewConfigMapReference(String lastUpdateTime,String name,String namespace,String resourceVersion,String uid);
    public CatalogSourceStatusFluent.ConfigMapReferenceNested<A> withNewConfigMapReference();
    public CatalogSourceStatusFluent.ConfigMapReferenceNested<A> withNewConfigMapReferenceLike(ConfigMapResourceReference item);
    public CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editConfigMapReference();
    public CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editOrNewConfigMapReference();
    public CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editOrNewConfigMapReferenceLike(ConfigMapResourceReference item);
    
/**
 * This method has been deprecated, please use method buildConnectionState instead.
 * @return The buildable object.
 */
@Deprecated public GRPCConnectionState getConnectionState();
    public GRPCConnectionState buildConnectionState();
    public A withConnectionState(GRPCConnectionState connectionState);
    public Boolean hasConnectionState();
    public A withNewConnectionState(String address,String lastConnect,String lastObservedState);
    public CatalogSourceStatusFluent.ConnectionStateNested<A> withNewConnectionState();
    public CatalogSourceStatusFluent.ConnectionStateNested<A> withNewConnectionStateLike(GRPCConnectionState item);
    public CatalogSourceStatusFluent.ConnectionStateNested<A> editConnectionState();
    public CatalogSourceStatusFluent.ConnectionStateNested<A> editOrNewConnectionState();
    public CatalogSourceStatusFluent.ConnectionStateNested<A> editOrNewConnectionStateLike(GRPCConnectionState item);
    public String getLatestImageRegistryPoll();
    public A withLatestImageRegistryPoll(String latestImageRegistryPoll);
    public Boolean hasLatestImageRegistryPoll();
    public A withNewLatestImageRegistryPoll(String arg1);
    public A withNewLatestImageRegistryPoll(StringBuilder arg1);
    public A withNewLatestImageRegistryPoll(StringBuffer arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(String arg1);
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(StringBuffer arg1);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(String arg1);
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildRegistryService instead.
 * @return The buildable object.
 */
@Deprecated public RegistryServiceStatus getRegistryService();
    public RegistryServiceStatus buildRegistryService();
    public A withRegistryService(RegistryServiceStatus registryService);
    public Boolean hasRegistryService();
    public A withNewRegistryService(String createdAt,String port,String protocol,String serviceName,String serviceNamespace);
    public CatalogSourceStatusFluent.RegistryServiceNested<A> withNewRegistryService();
    public CatalogSourceStatusFluent.RegistryServiceNested<A> withNewRegistryServiceLike(RegistryServiceStatus item);
    public CatalogSourceStatusFluent.RegistryServiceNested<A> editRegistryService();
    public CatalogSourceStatusFluent.RegistryServiceNested<A> editOrNewRegistryService();
    public CatalogSourceStatusFluent.RegistryServiceNested<A> editOrNewRegistryServiceLike(RegistryServiceStatus item);
    public interface ConfigMapReferenceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConfigMapResourceReferenceFluent<CatalogSourceStatusFluent.ConfigMapReferenceNested<N>> {

        public N and();
        public N endConfigMapReference();    }


    public interface ConnectionStateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,GRPCConnectionStateFluent<CatalogSourceStatusFluent.ConnectionStateNested<N>> {

        public N and();
        public N endConnectionState();    }


    public interface RegistryServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RegistryServiceStatusFluent<CatalogSourceStatusFluent.RegistryServiceNested<N>> {

        public N and();
        public N endRegistryService();    }


}

==> openshift-model-operatorhub-5.3.0-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/CatalogSourceStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface CatalogSourceStatusFluent<A extends CatalogSourceStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildConfigMapReference instead.
 * @return The buildable object.
 */
@Deprecated public ConfigMapResourceReference getConfigMapReference();
    public ConfigMapResourceReference buildConfigMapReference();
    public A withConfigMapReference(ConfigMapResourceReference configMapReference);
    public Boolean hasConfigMapReference();
    public A withNewConfigMapReference(String lastUpdateTime,String name,String namespace,String resourceVersion,String uid);
    public CatalogSourceStatusFluent.ConfigMapReferenceNested<A> withNewConfigMapReference();
    public CatalogSourceStatusFluent.ConfigMapReferenceNested<A> withNewConfigMapReferenceLike(ConfigMapResourceReference item);
    public CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editConfigMapReference();
    public CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editOrNewConfigMapReference();
    public CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editOrNewConfigMapReferenceLike(ConfigMapResourceReference item);
    
/**
 * This method has been deprecated, please use method buildConnectionState instead.
 * @return The buildable object.
 */
@Deprecated public GRPCConnectionState getConnectionState();
    public GRPCConnectionState buildConnectionState();
    public A withConnectionState(GRPCConnectionState connectionState);
    public Boolean hasConnectionState();
    public A withNewConnectionState(String address,String lastConnect,String lastObservedState);
    public CatalogSourceStatusFluent.ConnectionStateNested<A> withNewConnectionState();
    public CatalogSourceStatusFluent.ConnectionStateNested<A> withNewConnectionStateLike(GRPCConnectionState item);
    public CatalogSourceStatusFluent.ConnectionStateNested<A> editConnectionState();
    public CatalogSourceStatusFluent.ConnectionStateNested<A> editOrNewConnectionState();
    public CatalogSourceStatusFluent.ConnectionStateNested<A> editOrNewConnectionStateLike(GRPCConnectionState item);
    public String getLatestImageRegistryPoll();
    public A withLatestImageRegistryPoll(String latestImageRegistryPoll);
    public Boolean hasLatestImageRegistryPoll();
    public A withNewLatestImageRegistryPoll(StringBuilder arg1);
    public A withNewLatestImageRegistryPoll(int[] arg1,int arg2,int arg3);
    public A withNewLatestImageRegistryPoll(char[] arg1);
    public A withNewLatestImageRegistryPoll(StringBuffer arg1);
    public A withNewLatestImageRegistryPoll(byte[] arg1,int arg2);
    public A withNewLatestImageRegistryPoll(byte[] arg1);
    public A withNewLatestImageRegistryPoll(char[] arg1,int arg2,int arg3);
    public A withNewLatestImageRegistryPoll(byte[] arg1,int arg2,int arg3);
    public A withNewLatestImageRegistryPoll(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLatestImageRegistryPoll(String arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(int[] arg1,int arg2,int arg3);
    public A withNewMessage(char[] arg1);
    public A withNewMessage(StringBuffer arg1);
    public A withNewMessage(byte[] arg1,int arg2);
    public A withNewMessage(byte[] arg1);
    public A withNewMessage(char[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMessage(String arg1);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(int[] arg1,int arg2,int arg3);
    public A withNewReason(char[] arg1);
    public A withNewReason(StringBuffer arg1);
    public A withNewReason(byte[] arg1,int arg2);
    public A withNewReason(byte[] arg1);
    public A withNewReason(char[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewReason(String arg1);
    
/**
 * This method has been deprecated, please use method buildRegistryService instead.
 * @return The buildable object.
 */
@Deprecated public RegistryServiceStatus getRegistryService();
    public RegistryServiceStatus buildRegistryService();
    public A withRegistryService(RegistryServiceStatus registryService);
    public Boolean hasRegistryService();
    public A withNewRegistryService(String createdAt,String port,String protocol,String serviceName,String serviceNamespace);
    public CatalogSourceStatusFluent.RegistryServiceNested<A> withNewRegistryService();
    public CatalogSourceStatusFluent.RegistryServiceNested<A> withNewRegistryServiceLike(RegistryServiceStatus item);
    public CatalogSourceStatusFluent.RegistryServiceNested<A> editRegistryService();
    public CatalogSourceStatusFluent.RegistryServiceNested<A> editOrNewRegistryService();
    public CatalogSourceStatusFluent.RegistryServiceNested<A> editOrNewRegistryServiceLike(RegistryServiceStatus item);
    public interface ConfigMapReferenceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConfigMapResourceReferenceFluent<CatalogSourceStatusFluent.ConfigMapReferenceNested<N>> {

            public N and();
            public N endConfigMapReference();    }


    public interface ConnectionStateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,GRPCConnectionStateFluent<CatalogSourceStatusFluent.ConnectionStateNested<N>> {

            public N and();
            public N endConnectionState();    }


    public interface RegistryServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RegistryServiceStatusFluent<CatalogSourceStatusFluent.RegistryServiceNested<N>> {

            public N and();
            public N endRegistryService();    }


}
